summaryrefslogtreecommitdiffstats
path: root/source/AVR_Studio/Soccer/hal/board.h
diff options
context:
space:
mode:
Diffstat (limited to 'source/AVR_Studio/Soccer/hal/board.h')
-rwxr-xr-xsource/AVR_Studio/Soccer/hal/board.h42
1 files changed, 25 insertions, 17 deletions
diff --git a/source/AVR_Studio/Soccer/hal/board.h b/source/AVR_Studio/Soccer/hal/board.h
index 445ffa4..a76aeb7 100755
--- a/source/AVR_Studio/Soccer/hal/board.h
+++ b/source/AVR_Studio/Soccer/hal/board.h
@@ -11,26 +11,33 @@
#define BEEPER_PIN PG2
-// Definiere Konstanten für die Motoren/Dribbler
-#define MOTOR0_PORT PORTD
-#define MOTOR0_PWM OCR3A
-#define MOTOR0_A (1 << 5)
-#define MOTOR0_B (1 << 4)
+// Definiere Konstanten für die Motoren/Dribbler
+#define MOTOR0_PORT PORTB
+#define MOTOR0_PWM OCR1A
+#define MOTOR0_A (1 << 0)
+#define MOTOR0_B (1 << 1)
-#define MOTOR1_PORT PORTD
-#define MOTOR1_PWM OCR3B
-#define MOTOR1_A (1 << 6)
-#define MOTOR1_B (1 << 7)
+#define MOTOR1_PORT PORTB
+#define MOTOR1_PWM OCR1B
+#define MOTOR1_A (1 << 2)
+#define MOTOR1_B (1 << 3)
-#define MOTOR2_PORT PORTB
-#define MOTOR2_PWM OCR1A
-#define MOTOR2_A (1 << 0)
-#define MOTOR2_B (1 << 1)
+#define MOTOR2_PORT PORTD
+#define MOTOR2_PWM OCR3A
+#define MOTOR2_A (1 << 5)
+#define MOTOR2_B (1 << 4)
-#define DRIBBLER_PORT PORTB
-#define DRIBBLER_PWM OCR1C
-#define DRIBBLER_A (1 << 2)
-#define DRIBBLER_B (1 << 3)
+#define DRIBBLER_PORT PORTD
+#define DRIBBLER_PWMPORT PORTA
+#define DRIBBLER_PWM (1 << 5)
+#define DRIBBLER_A (1 << 6)
+#define DRIBBLER_B (1 << 7)
+
+// Kicker
+#define KICKER_AN PORTG |= (1 << PG3);
+#define KICKER_AUS PORTG &= ~(1 << PG3);
+#define KICKER_USLEEP 10
+
// Definiere Konstanten für Abstandsensoren
#define ABSTAND_PORT PORTC
@@ -54,6 +61,7 @@ public:
void ledOff();
void led(bool status);
void motor(int i, int speed);
+ void kicker();
};
#endif